==> gridsome-0.7.4.tgz: package/README.md <==
<p align="center">
  <br>
  <a href="https://www.gridsome.org">
    <img src="https://raw.githubusercontent.com/gridsome/gridsome/master/assets/logo.png" width="90"/>
  </a>
</p>

<h2 align="center">Gridsome</h2>

<p align="center">
  A JAMstack framework for building blazing fast websites with <a href="https://vuejs.org">Vue.js</a>
</p>

<p align="center">
  <a title="Total downloads" href="https://www.npmjs.com/package/gridsome">
    <img src="https://img.shields.io/npm/dt/gridsome.svg?style=flat-square">
  </a>
  <a title="Current version" href="https://www.npmjs.com/package/gridsome">
    <img src="https://img.shields.io/npm/v/gridsome.svg?style=flat-square">
  </a>
  <a title="MIT License" href="LICENSE">
    <img src="https://img.shields.io/github/license/gridsome/gridsome.svg?style=flat-square">
  </a>
  <a title="Follow on Twitter" href="https://twitter.com/gridsome">
    <img src="https://img.shields.io/twitter/follow/gridsome.svg?style=social&label=Follow">
  </a>
  <br>
  <br>
</p>

> This project is under active development. Any feedback or contributions would be appreciated.

Build websites using latest web tech tools that developers love - Vue.js, GraphQL and webpack. Use local files or any external API as a data source and access the data from a unified GraphQL layer. Gridsome is heavily inspired by **[Gatsby](https://gatsbyjs.org)**.

## Quick start

### 1. Install Gridsome CLI tool

`npm install --global @gridsome/cli`

### 2. Create a Gridsome project

1. `gridsome create my-gridsome-site` to create a new project </li>
2. `cd my-gridsome-site` to open folder
3. `gridsome develop` to start local dev server at `http://localhost:8080`
4. Happy coding 🎉🙌

### 3. Next steps

1. Create `.vue` components in the `~/src/pages` directory to create pages
2. Use `gridsome build` to generate static files in a `~/dist` folder

### Learn more...

- [How it works](https://gridsome.org/docs/how-it-works)
- [How to deploy](https://gridsome.org/docs/deployment)

==> gridsome-0.7.10.tgz: package/README.md <==
<p align="center">
  <br>
  <a href="https://www.gridsome.org">
    <img src="https://raw.githubusercontent.com/gridsome/gridsome/master/assets/logo.png" width="90"/>
  </a>
</p>

<h2 align="center">Gridsome</h2>

<p align="center">
  A JAMstack framework for building blazing fast websites with <a href="https://vuejs.org">Vue.js</a>
</p>

<p align="center">
  <a title="Total downloads" href="https://www.npmjs.com/package/gridsome">
    <img src="https://img.shields.io/npm/dt/gridsome.svg?style=flat-square">
  </a>
  <a title="Current version" href="https://www.npmjs.com/package/gridsome">
    <img src="https://img.shields.io/npm/v/gridsome.svg?style=flat-square">
  </a>
  <a title="MIT License" href="LICENSE">
    <img src="https://img.shields.io/github/license/gridsome/gridsome.svg?style=flat-square">
  </a>
  <a title="Follow on Twitter" href="https://twitter.com/gridsome">
    <img src="https://img.shields.io/twitter/follow/gridsome.svg?style=social&label=Follow">
  </a>
  <br>
  <br>
</p>

> This project is under active development. Any feedback or contributions would be appreciated.

Build websites using latest web tech tools that developers love - Vue.js, GraphQL and webpack. Use local files or any external API as a data source and access the data from a unified GraphQL layer. Gridsome is heavily inspired by **[Gatsby](https://gatsbyjs.org)**.

## Quick start

### 1. Install Gridsome CLI tool

`npm install --global @gridsome/cli`

### 2. Create a Gridsome project

1. `gridsome create my-gridsome-site` to create a new project </li>
2. `cd my-gridsome-site` to open folder
3. `gridsome develop` to start local dev server at `http://localhost:8080`
4. Happy coding 🎉🙌

### 3. Next steps

1. Create `.vue` components in the `./src/pages` directory to create pages
2. Use `gridsome build` to generate static files in a `./dist` folder

### Learn more...

- [How it works](https://gridsome.org/docs/how-it-works)
- [How to deploy](https://gridsome.org/docs/deployment)
